
__version__ = "1.7.0"
docs = r"https://alexlib.readthedocs.io/en/latest/"
git = r"https://github.com/thisismygitrepo/alexlib"
release_notes = """

Added tutorial
"""
